# Demonstrating updates and additions

This document was derived from the processing of the file dr_egeria_intro.md; All of the Dr.Egeria statements have been
preserved (including the generated attributes such as the unique GUIDs) and the explanatory text has been replaced.

In this document we will add glossary categories, update existing terms to categorize them, and add some new terms that
further explain dr.egeria.  This document is being written off-line (actually on a plane) - demonstrating one of the
intriguing features of dr.egeria - because its just text, it can be edited anywhere and anytime that there is a text
editor. Dr.Egeria files can be emailed, sent via text message, slack or maintained in a `git` repository.
It's just text with markdown annotations.

Ok, let's get started. First, we have the `Update Glossary` command below. There is nothing new we need to add at this
point so we can just leave it as-is. When this document is processed it will apply updates but if there are none,
It doesn't matter.


---


# Update Glossary

## Glossary Name 

Egeria-Markdown

## Description
Glossary to describe the vocabulary of Dr.Egeria - an Egeria Markdown language to support the exchange of metadata in a Markdown form.
Dr.Egeria allows users to input metadata using any text entry system that supports the entry of standard Markdown
notation and through post-processing
commands, validates the Egeria content and allows the requests to be sent to Egeria.

## Language
English

## Usage
1. (optional) load an example or template for the type of object from Egeria.
2. Create a new document (perhaps from a template) and edit it, adding in the content with the Dr.Egeria controlled Markdown language.
3. Process the document to validate and display it before you submit it, Validation may annotate your document with recommendations and potential issues.
4. Submit the document to Egeria using the Dr.Egeria commands.

## Qualified Name
Glossary::Egeria-Markdown

## Guid
5878850f-0fc5-484d-8426-511c18615a66



Ok, now let's create a couple of glossary categories. They will be:

* **Writing Dr.Egeria Markdown** - where we describe elements of the Dr.Egeria language as terms within the category.
* **Processing Dr.Egeria Markdown** - where we describe the commands for processing Dr.Egeria.


Glossary categories have the following attributes:

| Attribute Name | Input Required? | Generated/Default? | Unique? | Notes |
|:-|:-|:-|:-|:-|
| Category Name | Yes | No | No | A display name (informal name). |
| Owning Glossary | Yes | No | Yes | This is the qualified name of the glossary that owns this category. |
| Description | No | No  | No | A textual description of this category |
| Qualified Name | No | Yes | Yes | The qualified name can either be provided by the user or generated. If generated, a pattern is followed. |
| GUID | No | Yes | Yes | GUIDs are always generated by Egeria. They are meant for automation, not people. |

Qualified Names can either be user specified or generated. If generated the following the form:
`{local-qualifier}:{type}:{display name}`

* Local-Qualifier is an optional string that can be useful to both disambiguate similar names and to add some local context. Local qualifiers could be set to organization names, functions, business context, etc. The settings for a local qualifier is set either by setting the environment variable `EGERIA_LOCAL_QUALIFIER` or by passing in a parameter when executing one of the Dr.Egeria enabled commands. This could also be set for a team by an Egeria administrator.



# Update Categories

## Category Name 

Writing Dr.Egeria Markdown

## Description
These terms describe the elements of the Dr.Egeria Markdown language and how to use them.

## In Glossary
Glossary::Egeria-Markdown

## Qualified Name
Category:Writing-Dr.Egeria-Markdown

## Guid
c5ba25df-f7b1-4ecf-913a-c5c83a03d63a


---




# Update Categories

## Category Name 

Processing Dr.Egeria Markdown

## Description
These terms describe commands to process Dr.Egeria Markdown.

## In Glossary
Glossary::Egeria-Markdown

## Qualified Name
Category:Processing-Dr.Egeria-Markdown

## Guid
1f13ec0d-e0ad-4327-bc1c-58e4174dd950


---



Ok now, let's add categories to some of the terms.  Let's review the attributes of a term:

| Attribute Name  | Input Required? | Generated/Default? | Unique? | Notes |
|:----------------| :- | :- | :- | :-|
| Term Name       | Yes | No | No | A display name (informal name). |
| Owning Glossary | Yes | No | Yes | This is the qualified name of the glossary that owns this term. |
| Categories      | No | No | Yes | This is the qualified (unique) name of the category. Multiple categories can be assigned, separated by a `,` or line. |
| Description     | No | No  | No | A textual description of this term |
| Qualified Name  | No | Yes | Yes | The qualified name can either be provided by the user or generated. If generated, a pattern is followed. |
| GUID            | No | Yes | Yes | GUIDs are always generated by Egeria. They are meant for automation, not people. |



# Update Term

## Term Name 

Command

## Summary
Commands are how a user of the Freddie markdown language requests an action.

## In Glossary
Glossary::Egeria-Markdown

## Categories
Category:Processing-Dr.Egeria-Markdown
, Category:Writing-Dr.Egeria-Markdown

## Status
DRAFT

## Description
Commands are how a user can request Egeria to take an action such as Create or Update an Egeria element. Freddie
provides
a limited (but growing) set of commands. Freddie commands align with the pyegeria 'hey-egeria' command line interface.

## Examples
Create Glossary or
Update Glossary or
Create Term or
Update Term

## Usage
Commands are used in the Freddie Egeria markdown language.

## Published Version
0.1

## Qualified Name
Term:Command

## Guid
f59ca92e-9021-42bb-ae20-68fbbed57a86


---



# Update Term

## Term Name 

Source

## Summary
Source of the markdown content.

## In Glossary
Glossary::Egeria-Markdown

## Categories
Category:Processing-Dr.Egeria-Markdown

## Status
DRAFT

## Description
Source of the markdown content - could be jupyter or plain markdown file.

## Examples
None

## Usage
None

## Version
0.1

## Qualified Name
Term:Source

## Guid
fec76950-8a4b-4f20-9032-2b3775adee2c


---



# Update Term

## Term Name 

Directive

## Summary
A directive defines how the command is to be processed.

## In Glossary
Glossary::Egeria-Markdown

## Categories
Category:Processing-Dr.Egeria-Markdown

## Status
DRAFT

## Description
Directives are one of:
* display - just display what we've found
* validate - check the validity of the requested action
* process - process the requested action
* review?

## Examples
None

## Usage
None

## Published Version
0.2

## Qualified Name
Term:Directive

## Guid
fa716e1d-bd97-44e7-b64c-594cb8c2867c


---


# Provenance
 
* t2.md Derived from processing file dr_egeria_intro_part2.md on 2025-03-20 15:06

---